==> order-center-domain-2.0.9-CLOUD-TEST-20220420.223101-97-sources.jar: com/tydic/dyc/oc/model/saleorder/sub/UocSaleStakeholder.java <==
package com.tydic.dyc.oc.model.saleorder.sub;

import com.tydic.utils.generatedoc.annotation.DocField;
import lombok.Data;

import java.io.Serializable;
import java.util.Date;

/**
 * 标题:UocSaleStakeholder
 * 说明:记录买方、卖方、平台三方信息
 * 时间:2022-02-21 19:11
 * 作者:罗有
 **/
@Data
public class UocSaleStakeholder implements Serializable {
	private static final long serialVersionUID =  4648777654165421921L;

	@DocField(value = "三方信息id")
	private Long stakeholderId;

	@DocField(value = "订单id")
	private Long orderId;

	@DocField(value = "采购方账套id")
	private String purAccount;

	@DocField(value = "采购方账套名称")
	private String purAccountName;

	@DocField(value = "采购方联系人电话")
	private String purMobile;

	@DocField(value = "采购方下单人用户id")
	private String purUserId;

	@DocField(value = "采购方下单人真实姓名")
	private String purName;

	@DocField(value = "采购方下单人登录名")
	private String purUserName;

	@DocField(value = "采购方公司id")
	private String purCompanyId;

	@DocField(value = "采购公司编码")
	private String purCompanyNo;

	@DocField(value = "采购方公司名称")
	private String purCompanyName;

	@DocField(value = "采购方机构id")
	private String purOrgId;

	@DocField(value = "采购方机构编码")
	private String purOrgNo;

	@DocField(value = "采购方机构名称")
	private String purOrgName;

	@DocField(value = "下单组织机构路径")
	private String purOrgPath;

	@DocField(value = "需方联系人名称")
	private String purNeedName;

	@DocField(value = "需方联系电话")
	private String purNeedMobile;

	@DocField(value = "供应商id")
	private String supId;

	@DocField(value = "供应商编码")
	private String supNo;

	@DocField(value = "供应商名称")
	private String supName;

	@DocField(value = "供应商联系人")
	private String supRelaName;

	@DocField(value = "供应商联系电话")
	private String supRelaMobile;

	@DocField(value = "运营单位机构id")
	private String proId;

	@DocField(value = "运营单位机构编码")
	private String proNo;

	@DocField(value = "运营机构名称")
	private String proName;

	@DocField(value = "运营机构机构树路径")
	private String proOrgPath;

	@DocField(value = "运营机构账户名称")
	private String proAccountName;

	@DocField(value = "运营机构账户")
	private String proAccount;

	@DocField(value = "运营机构联系人")
	private String proRelaName;

	@DocField(value = "运营机构联系电话")
	private String proRelaMobile;

	@DocField(value = "更新时间")
	private Date updateTime;

	@DocField(value = "更新工号")
	private String updateOperId;

	@DocField(value = "备注")
	private String remark;

	

	

}

==> order-center-domain-3.1.0-CLOUD-TEST-20230104.101326-12-sources.jar: com/tydic/dyc/oc/model/saleorder/sub/UocSaleStakeholder.java <==
package com.tydic.dyc.oc.model.saleorder.sub;

import com.tydic.utils.generatedoc.annotation.DocField;
import lombok.Data;

import java.io.Serializable;
import java.util.Date;

/**
 * 标题:UocSaleStakeholder
 * 说明:记录买方、卖方、平台三方信息
 * 时间:2022-02-21 19:11
 * 作者:罗有
 **/
@Data
public class UocSaleStakeholder implements Serializable {
	private static final long serialVersionUID =  4648777654165421921L;

	@DocField(value = "三方信息id")
	private Long stakeholderId;

	@DocField(value = "订单id")
	private Long orderId;

	@DocField(value = "采购方账套id")
	private String purAccount;

	@DocField(value = "采购方账套名称")
	private String purAccountName;

	@DocField("采购方联系人")
	private String purContactName;

	@DocField(value = "采购方联系人电话")
	private String purMobile;

	@DocField(value = "采购方下单人用户id")
	private String purUserId;

	@DocField(value = "采购方下单人真实姓名")
	private String purName;

	@DocField(value = "采购方下单人登录名")
	private String purUserName;

	@DocField(value = "采购方公司id")
	private String purCompanyId;

	@DocField(value = "采购公司编码")
	private String purCompanyNo;

	@DocField(value = "采购方公司名称")
	private String purCompanyName;

	@DocField(value = "采购方机构id")
	private String purOrgId;

	@DocField(value = "采购方机构编码")
	private String purOrgNo;

	@DocField(value = "采购方机构名称")
	private String purOrgName;

	@DocField(value = "下单组织机构路径")
	private String purOrgPath;

	@DocField(value = "需方联系人名称")
	private String purNeedName;

	@DocField(value = "需方联系电话")
	private String purNeedMobile;

	@DocField(value = "供应商id")
	private String supId;

	@DocField(value = "供应商编码")
	private String supNo;

	@DocField(value = "供应商名称")
	private String supName;

	@DocField(value = "供应商联系人")
	private String supRelaName;

	@DocField(value = "供应商联系电话")
	private String supRelaMobile;

	@DocField(value = "运营单位机构id")
	private String proId;

	@DocField(value = "运营单位机构编码")
	private String proNo;

	@DocField(value = "运营机构名称")
	private String proName;

	@DocField(value = "运营机构机构树路径")
	private String proOrgPath;

	@DocField(value = "运营机构账户名称")
	private String proAccountName;

	@DocField(value = "运营机构账户")
	private String proAccount;

	@DocField(value = "运营机构联系人")
	private String proRelaName;

	@DocField(value = "运营机构联系电话")
	private String proRelaMobile;

	@DocField(value = "更新时间")
	private Date updateTime;

	@DocField(value = "更新工号")
	private String updateOperId;

	@DocField(value = "备注")
	private String remark;

	@DocField(value = "供应商机构树")
	private String supOrgPath;

	

}
